/*#############################################################
File Name       : ex2_HC06_leds.c
Author          : Grant Phillips
Date Modified   : 12/10/2015
Compiler        : Keil ARM-MDK (uVision V4.70.0.0)
Tested On       : STM32F429I-Discovery

Description     : Example program that uses the USART1 module to 
									establish a serial link via a HC-06 Bluetooth
									module with another device.  If the STM32F429I
									receives the following character:
									"A"		-	GREEN LED (LD3) ON
									"B"		-	GREEN LED (LD3) OFF
									"C"		-	RED LED (LD4) ON
									"D"		-	RED LED (LD4) OFF 

Requirements    : * STM32F429I-Discovery Board
									* Make sure the STM32F429I_Defaults.c file is 
										in the same folder than the project
									* Make sure the HC06_F429I.c file is in the 
                    same folder than the project
              
Circuit         : * 2 LEDs connected to PG13 - PG4 (LD3 - LD4
                    ON STM32F429I-DISCOVERY BOARD)
									* HC06 Bluetooth module is connected as follows:
										TXD			-		PA10
										RXD			-		PA9
										GND			-		GND
										VCC			-		3.3V

See the STM32F429I-Discovery User Manual (UM1670) for the block 
diagram of the STM32F429ZIT6 processor (p11), a summary of the 
GPIO connections and free IO pins (p19-25) and the schematic 
diagram (p27-33).
##############################################################*/

#include "STM32F429I_Defaults.c"																//library for the defaults of a blank project in Keil uVision
#include "HC06_F429I.c"																					//for the HC06 functions on the STM32F429I-Discovery


void InitLEDs(void);																					  //prototype for the user function to initialize the USER LEDs


int main(void)
{
	/* Set the SysTick Interrupt to occur every 1ms) */
	if (SysTick_Config(SystemCoreClock / 1000))
  { 
    while (1);																									//will end up in this infinite loop if there was an error with Systick_Config
  }
	
	HC06_Init(115200);											//initialize the HC-06 module at 115200 baud
	
	InitLEDs();															//initialize the USER LEDs for this application
	
	HC06_ClearRxBuffer();										//Clear the Receive buffer from any unwanted characters after the setup was done
	
	/* Main program loop */
  while (1)
  {
		if(new_HC06_msg)															//check if there is a new message
		{
			if(strcmp(HC06_msg, "A") == 0)							//GREEN LED (LD3) ON
				GPIO_WriteBit (GPIOG, GPIO_Pin_13, Bit_SET);
			else if(strcmp(HC06_msg, "B") == 0)					//GREEN LED (LD3) OFF
				GPIO_WriteBit (GPIOG, GPIO_Pin_13, Bit_RESET);
			else if(strcmp(HC06_msg, "C") == 0)					//RED LED (LD4) ON
				GPIO_WriteBit (GPIOG, GPIO_Pin_14, Bit_SET);
			else if(strcmp(HC06_msg, "D") == 0)					//RED LED (LD4) OFF
				GPIO_WriteBit (GPIOG, GPIO_Pin_14, Bit_RESET);
			else
				HC06_PutStr("Incorrect command\n");				//Reply incorrect command
				
			new_HC06_msg=0;															//clear message flag
		}
	}
}



void InitLEDs(void)
{
	GPIO_InitTypeDef        GPIO_InitStructure;										//structure used for setting up a GPIO port
	
  /* GPIOG Periph clock enable */
  RCC_AHB1PeriphClockCmd(RCC_AHB1Periph_GPIOG, ENABLE);           
  
  /* Configure PG14 - PG13 in output pushpull mode */
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_14 | GPIO_Pin_13;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT;               
  GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;                       
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;                    
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL;                     
  GPIO_Init(GPIOG, &GPIO_InitStructure);                                    
}

